@@ -222,6 +222,13 @@ class FakeClient(SocialtextClient):
             'location': '/data/groups/21'
         })
 
+    def post_data_groups_21_trash(self, **kw):
+        assert_has_keys(kw, required=["data"])
+        body = kw["data"]
+        for item in body:
+            assert_has_keys(item, optional=["workspace_id", "user_id"])
+        return resp(200, None)
+
     ###########
     # SIGNALS #
     ###########
