@@ -25,7 +25,7 @@ def test_get_id():
 def test_eq():
     # two resources of different types: never equal
     r1 = Resource(None, {'id': 1})
-    r2 = Signal(None, {'signal_id': 1})
+    r2 = Signal(cs.signals, {'signal_id': 1})
     assert_not_equal(r1, r2)
     
     # Two resources with no ID: equal if their info is equal
