@@ -1,13 +1,16 @@
 from unittest import TestCase
 from nose.tools import assert_equal
+from tests.fakeserver import FakeServer
 from tests.utils import assert_isinstance
 
 from socialtext.resources.signals import Signal
 
+st = FakeServer()
+
 def test_get_mentioned_user_ids():
     # test signal mention
     body = "Hello {user: 123}!"
-    signal = Signal(None, {"body": body})
+    signal = Signal(st.signals, {"body": body})
     assert_equal(['123'], signal.get_mentioned_user_ids())
 
     # test multiple mentions
@@ -20,7 +23,7 @@ def test_get_mentioned_user_ids():
 def test_is_user_mentioned():
     # User 123 is mentioned in this signal
     body = "Hello {user: 123}!"
-    signal = Signal(None, {"body": body})
+    signal = Signal(st.signals, {"body": body})
     assert_equal(True, signal.is_user_mentioned(123))
 
     # User 123 isn't mentioned in this signal
